import { CUSTOM_ELEMENTS_SCHEMA, ErrorHandler, NgModule } from '@angular/core';
import { CalendarModule, DateAdapter } from 'angular-calendar';
import { CommonModule, CurrencyPipe, TitleCasePipe } from '@angular/common';
import { HTTP_INTERCEPTORS, HttpClientModule } from '@angular/common/http';
import { AppRoutingModule } from './app-routing.module';
import { AuthGuard } from '@providers/authentication/auth-guard.service';
import { AuthTokenInterceptor } from '@providers/authentication/authentication.service.interceptor';
import { BrowserAnimationsModule } from '@angular/platform-browser/animations';
import { BrowserModule } from '@angular/platform-browser';
import { FormsModule } from '@angular/forms';
import { Geolocation } from '@ionic-native/geolocation/ngx';
import { GlobalErrorHandler } from '@providers/error-handling/global-error-handler';
import { IonicModule } from '@ionic/angular';
import { IonicStorageModule } from '@ionic/storage';
import { JwtHelperService } from '@auth0/angular-jwt';
import { LandingPageModule } from '@scorpion/ionic/features/landing/landing.module';
import { LazyLoadingScriptService } from '@scorpion/shared/providers/script-lazy-loading/script-lazy-loading.service';
import { LocationTrackingService } from '@providers/location-tracking/location-tracking.service';
import { MenuPopoverModule } from '@scorpion/ionic/features/popups-and-modals/menu-popover/menu-popover.module';
import { MessageBannerService } from '@providers/messaging/message-banner.service';
import { PageNotFoundModule } from './features/page-not-found';
import { ScorpionCrmMobilePage } from './app.component';
import { SharedDataService } from '@providers/shared-data/shared-data.service';
import { adapterFactory } from 'angular-calendar/date-adapters/date-fns';
import { EstimatePagesService } from '@scorpion/ionic/features/estimates/services/edit-estimate.service';
import { SpinnerDialog } from '@ionic-native/spinner-dialog/ngx';
import { PricebookService } from '@scorpion/ionic/features/pricebook/services/pricebook.service';
import { File } from '@ionic-native/file/ngx';
import { WebView } from '@ionic-native/ionic-webview/ngx';
import { Base64 } from '@ionic-native/base64/ngx';
import BackgroundGeolocation from 'cordova-background-geolocation-lt';

@NgModule({
    declarations: [ScorpionCrmMobilePage],
    imports: [
        AppRoutingModule,
        BrowserAnimationsModule,
        BrowserModule,
        CalendarModule.forRoot({ provide: DateAdapter, useFactory: adapterFactory }),
        CommonModule,
        FormsModule,
        HttpClientModule,
        IonicModule.forRoot({ backButtonText: '', scrollAssist: false }),
        IonicStorageModule.forRoot(),
        LandingPageModule,
        MenuPopoverModule,
        PageNotFoundModule
    ],
    bootstrap: [ScorpionCrmMobilePage],
    entryComponents: [],
    providers: [
        { provide: ErrorHandler, useClass: GlobalErrorHandler },
        { provide: HTTP_INTERCEPTORS, useClass: AuthTokenInterceptor, multi: true },
        // { provide: LocationStrategy, useClass: PathLocationStrategy },
        //        { provide: RouteReuseStrategy, useClass: IonicRouteStrategy },
        AuthGuard,
        BackgroundGeolocation,
        CurrencyPipe,
        EstimatePagesService,
        Geolocation,
        JwtHelperService,
        LazyLoadingScriptService,
        LocationTrackingService,
        MessageBannerService,
        PricebookService,
        SharedDataService,
        TitleCasePipe,
        SpinnerDialog,
        File,
        WebView,
        Base64
    ],
    schemas: [CUSTOM_ELEMENTS_SCHEMA]
})
export class AppModule {}
